# mypy-boto3-kendra

[![PyPI - mypy-boto3-kendra](https://img.shields.io/pypi/v/mypy-boto3-kendra.svg?color=blue)](https://pypi.org/project/mypy-boto3-kendra)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-kendra.svg?color=blue)](https://pypi.org/project/mypy-boto3-kendra)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Kendra 1.17.2](https://boto3.amazonaws.com/v1/documentation/api/1.17.2/reference/services/kendra.html#Kendra) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-kendra](#mypy-boto3-kendra)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Kendra` service.

```bash
python -m pip install boto3-stubs[kendra]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[kendra]` in your environment: `python -m pip install 'boto3-stubs[kendra]'`

Both type checking and auto-complete should work for `Kendra` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[kendra]` in your environment: `python -m pip install 'boto3-stubs[kendra]'`

Both type checking and auto-complete should work for `Kendra` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[kendra]` in your environment: `python -m pip install 'boto3-stubs[kendra]'`
- Run `mypy` as usual

Type checking should work for `Kendra` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[kendra]` in your environment: `python -m pip install 'boto3-stubs[kendra]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Kendra` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`KendraClient` provides annotations for `boto3.client("kendra")`.

```python
import boto3

from mypy_boto3_kendra import KendraClient

client: KendraClient = boto3.client("kendra")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: KendraClient = session.client("kendra")
```








### Typed dictionations

`mypy_boto3_kendra.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_kendra.type_defs import (
    AccessControlListConfigurationTypeDef,
    AclConfigurationTypeDef,
    AdditionalResultAttributeTypeDef,
    AdditionalResultAttributeValueTypeDef,
    AttributeFilterTypeDef,
    BatchDeleteDocumentResponseFailedDocumentTypeDef,
    BatchDeleteDocumentResponseTypeDef,
    BatchPutDocumentResponseFailedDocumentTypeDef,
    BatchPutDocumentResponseTypeDef,
    CapacityUnitsConfigurationTypeDef,
    ClickFeedbackTypeDef,
    ColumnConfigurationTypeDef,
    ConfluenceAttachmentConfigurationTypeDef,
    ConfluenceAttachmentToIndexFieldMappingTypeDef,
    ConfluenceBlogConfigurationTypeDef,
    ConfluenceBlogToIndexFieldMappingTypeDef,
    ConfluenceConfigurationTypeDef,
    ConfluencePageConfigurationTypeDef,
    ConfluencePageToIndexFieldMappingTypeDef,
    ConfluenceSpaceConfigurationTypeDef,
    ConfluenceSpaceToIndexFieldMappingTypeDef,
    ConnectionConfigurationTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateFaqResponseTypeDef,
    CreateIndexResponseTypeDef,
    CreateThesaurusResponseTypeDef,
    DatabaseConfigurationTypeDef,
    DataSourceConfigurationTypeDef,
    DataSourceSummaryTypeDef,
    DataSourceSyncJobMetricsTypeDef,
    DataSourceSyncJobMetricTargetTypeDef,
    DataSourceSyncJobTypeDef,
    DataSourceToIndexFieldMappingTypeDef,
    DataSourceVpcConfigurationTypeDef,
    DescribeDataSourceResponseTypeDef,
    DescribeFaqResponseTypeDef,
    DescribeIndexResponseTypeDef,
    DescribeThesaurusResponseTypeDef,
    DocumentAttributeTypeDef,
    DocumentAttributeValueCountPairTypeDef,
    DocumentAttributeValueTypeDef,
    DocumentMetadataConfigurationTypeDef,
    DocumentsMetadataConfigurationTypeDef,
    DocumentTypeDef,
    FacetResultTypeDef,
    FacetTypeDef,
    FaqStatisticsTypeDef,
    FaqSummaryTypeDef,
    GoogleDriveConfigurationTypeDef,
    HighlightTypeDef,
    IndexConfigurationSummaryTypeDef,
    IndexStatisticsTypeDef,
    JsonTokenTypeConfigurationTypeDef,
    JwtTokenTypeConfigurationTypeDef,
    ListDataSourcesResponseTypeDef,
    ListDataSourceSyncJobsResponseTypeDef,
    ListFaqsResponseTypeDef,
    ListIndicesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListThesauriResponseTypeDef,
    OneDriveConfigurationTypeDef,
    OneDriveUsersTypeDef,
    PrincipalTypeDef,
    QueryResultItemTypeDef,
    QueryResultTypeDef,
    RelevanceFeedbackTypeDef,
    RelevanceTypeDef,
    S3DataSourceConfigurationTypeDef,
    S3PathTypeDef,
    SalesforceChatterFeedConfigurationTypeDef,
    SalesforceConfigurationTypeDef,
    SalesforceCustomKnowledgeArticleTypeConfigurationTypeDef,
    SalesforceKnowledgeArticleConfigurationTypeDef,
    SalesforceStandardKnowledgeArticleTypeConfigurationTypeDef,
    SalesforceStandardObjectAttachmentConfigurationTypeDef,
    SalesforceStandardObjectConfigurationTypeDef,
    ScoreAttributesTypeDef,
    SearchTypeDef,
    ServerSideEncryptionConfigurationTypeDef,
    ServiceNowConfigurationTypeDef,
    ServiceNowKnowledgeArticleConfigurationTypeDef,
    ServiceNowServiceCatalogConfigurationTypeDef,
    SharePointConfigurationTypeDef,
    SortingConfigurationTypeDef,
    SqlConfigurationTypeDef,
    StartDataSourceSyncJobResponseTypeDef,
    TagTypeDef,
    TextDocumentStatisticsTypeDef,
    TextWithHighlightsTypeDef,
    ThesaurusSummaryTypeDef,
    TimeRangeTypeDef,
    UserContextTypeDef,
    UserTokenConfigurationTypeDef,
)

def get_structure() -> AccessControlListConfigurationTypeDef:
    return {
      ...
    }
```
